#
# spec file for package talhelper
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           talhelper
Version:        3.0.29
Release:        1.1
Summary:        Tool to help creating Talos kubernetes cluster
License:        BSD-3-Clause
URL:            https://github.com/budimanjojo/talhelper
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.24
BuildRequires:  zsh

%description
The main reason of this tool is to help creating Talos cluster in GitOps way.
Inspired by a python script written by @bjw-s.

You can use this tool to generate Talos config file with talhelper genconfig
command. You can also use this tool to generate Talos secrets with talhelper
gensecret command.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/budimanjojo/talhelper/v3/cmd.version=%{version}" \
   -o bin/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%check
./bin/%{name} --version | grep %{version}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Fri Jun 13 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.29:
  * docs: update CLI reference documentation (#1054)
  * chore(deps): update dependency siderolabs/talos to v1.10.4
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.10.4
  * chore(schema): update talos-extensions.yaml JSON schema (#1052)
  * docs: add section to installing from nixpkgs
  * chore(github-action): update renovatebot/github-action action
    to v42.0.5
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.10.2
  * chore(schema): update talos-extensions.yaml JSON schema
  * feat(genurl): allow sprig functions for installer and iso
    templates
  * fix(deps): update module golang.org/x/mod to v0.25.0
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.11.0-alpha.1
  * fix(deps): update module github.com/siderolabs/image-factory to
    v0.7.3
  * chore(schema): update talos-extensions.yaml JSON schema (#1044)
  * chore(schema): update talos-extensions.yaml JSON schema (#1040)
  * chore(schema): update talos-extensions.yaml JSON schema (#1039)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.28
  * feat: update Scoop for talhelper version v3.0.28
  * feat: update flake (#1037)
* Sat May 31 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.28:
  * docs: update CLI reference documentation (#1036)
  * chore(deps): update dependency siderolabs/talos to v1.10.3
  * chore(container): update alpine docker tag to v3.22.0
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.27
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.10.3
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.24-bookworm docker digest
    to f7a7406 (#1034)
  * chore(schema): update talos-extensions.yaml JSON schema (#1033)
  * feat(CI): update script to show error and fix deprecation
    warnings
  * feat: update Scoop for talhelper version v3.0.27
  * feat: update flake (#1029)
* Sat May 31 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.27:
  * chore(deps): update dependency go to v1.24.3
  * feat(CI): update script to show error and fix depreciation
    warnings
  * feat(flake): update flake
  * fix(deps): update module github.com/siderolabs/image-factory to
    v0.7.1
  * chore(schema): update talos-extensions.yaml JSON schema
  * fix(deps): update module github.com/gookit/validate to v1.5.5
  * chore(github-action): update renovatebot/github-action action
    to v42.0.4
  * chore(schema): update talos-extensions.yaml JSON schema (#1025)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.26
  * feat: update Scoop for talhelper version v3.0.26
  * feat: update flake (#1022)
* Sun May 25 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.26:
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(schema): update talos-extensions.yaml JSON schema (#1020)
  * fix(docs): remove duplicated entry
  * fix(deps): update module github.com/google/go-containerregistry
    to v0.20.5
  * chore(schema): update talos-extensions.yaml JSON schema (#1018)
  * fix(deps): update module github.com/google/go-containerregistry
    to v0.20.4
  * docs: tweaked documentation a bit (#1014)
  * feat(config): allow go template inside `extraManifests` files
  * chore(github-action): update renovatebot/github-action action
    to v42.0.3
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.25
  * feat: update Scoop for talhelper version v3.0.25
  * feat: update flake (#1009)
* Sat May 17 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.25:
  * docs: update CLI reference documentation (#1008)
  * chore(deps): update dependency siderolabs/talos to v1.10.2
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.10.2
  * chore(schema): update talos-extensions.yaml JSON schema (#1007)
  * chore(container): update registry.k8s.io/kubectl docker tag to
    v1.33.1
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(schema): update talos-extensions.yaml JSON schema (#1002)
  * feat(genconfig): verbose warning instead when secrets file is
    not found
  * chore(github-action): update renovatebot/github-action action
    to v42.0.2
  * feat(genconfig): only append extra kernel args when not using
    UKI image
  * chore(schema): update talos-extensions.yaml JSON schema (#997)
  * chore(schema): update talos-extensions.yaml JSON schema (#996)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.24
  * feat: update Scoop for talhelper version v3.0.24
  * feat: update flake (#992)
* Thu May  8 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.24:
  * docs: update CLI reference documentation (#991)
  * chore(deps): update dependency siderolabs/talos to v1.10.1
  * chore(github-action): update actions/setup-go action to v5.5.0
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.10.1
  * feat(genconfig): reflect to the installer image url change
  * chore(schema): update talos-extensions.yaml JSON schema (#989)
  * chore(schema): update talconfig.yaml JSON schema (#985)
  * fix(code): make `golangci-lint` happy
  * docs(reference): update docs
  * feat(genconfig): support changing the output file name
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.24-bookworm docker digest
    to be739eb (#984)
  * chore(github-action): update renovatebot/github-action action
    to v42.0.1
  * chore(schema): update talos-extensions.yaml JSON schema (#980)
  * chore(github-action)!: Update golangci/golangci-lint-action
    action to v8
  * feat(readme): thank you @oliverbaehler for the sponsor!
  * chore(schema): update talos-extensions.yaml JSON schema (#977)
  * chore(container): update golangci/golangci-lint docker tag to
    v2.1.6
  * chore(github-action)!: Update renovatebot/github-action action
    to v42
  * chore(schema): update talconfig.yaml JSON schema (#972)
  * fix(schema): fix json schema for `volumes` and `userVolumes`
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.23
  * feat: update flake
  * feat: update Scoop for talhelper version v3.0.23
* Fri May  2 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.23:
  * feat: add `v1.11` as supported version
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.11.0-alpha.0
  * fix(deps): update module github.com/siderolabs/image-factory to
    v0.7.0
  * chore(schema): update talos-extensions.yaml JSON schema (#967)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.22
  * feat: update Scoop for talhelper version v3.0.22
  * feat: update flake (#963)
* Fri May  2 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.22:
  * docs: update CLI reference documentation (#962)
  * chore(deps): update dependency siderolabs/talos to v1.10.0
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.10.0
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.10.0
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.9.0
  * chore(schema): update talos-extensions.yaml JSON schema (#956)
  * fix(deps): update module github.com/siderolabs/image-factory to
    v0.6.9
  * chore(schema): update talos-extensions.yaml JSON schema (#955)
  * chore(github-action): update renovatebot/github-action action
    to v41.0.22
  * chore(container): update golangci/golangci-lint docker tag to
    v2.1.5
  * feat(test): seems like the image factory doesn't like our
    workflow
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.10.0-beta.1
  * chore(container): update registry.k8s.io/kubectl docker tag to
    v1.33.0
  * chore(container): update registry.k8s.io/kubectl docker tag to
    v1.32.4
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(github-action): update renovatebot/github-action action
    to v41.0.21
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(schema): update talconfig.yaml JSON schema (#944)
  * feat(config): add `userVolumes` to generate `UserVolumeConfig`
  * feat(config): deprecate `machineDisks`
  * chore(schema): update talos-extensions.yaml JSON schema (#942)
  * fix(code): ignore deprecated warnings on golangci-lint
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.10.0-beta.0
  * chore(container): update golangci/golangci-lint docker tag to
    v2.1.2
  * chore(container): update golangci/golangci-lint docker tag to
    v2.1.1
  * chore(github-action): update renovatebot/github-action action
    to v41.0.20
  * chore(container): update ghcr.io/getsops/sops docker tag to
    v3.10.2
  * fix(deps): update module github.com/getsops/sops/v3 to v3.10.2
  * fix: home-operations
  * chore(schema): update talos-extensions.yaml JSON schema (#938)
  * chore(github-action): update renovatebot/github-action action
    to v41.0.19
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.24-bookworm docker digest
    to fb6bc4a (#929)
  * docs: update CLI reference documentation (#930)
  * fix: lint issue move to switch case in pathsubst
  * fix: flip & rename flag to disable-nodes-section
  * feat: do not include nodes per default in talosconfig toggle
    with --list-nodes
  * fix(loader): paths of `extraManifests` should be relative to
    config file
  * chore(schema): update talos-extensions.yaml JSON schema (#925)
  * chore(schema): update talos-extensions.yaml JSON schema (#924)
  * feat(golangci): update `golangci-lint` to v2
  * chore(github-action)!: Update golangci/golangci-lint-action
    action to v7
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.8.2
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(deps): update dependency go to v1.24.2
  * chore(github-action): update renovatebot/github-action action
    to v41.0.18
  * fix(deps): update module github.com/getsops/sops/v3 to v3.10.1
  * chore(container): update ghcr.io/getsops/sops docker tag to
    v3.10.1
  * chore(schema): update talos-extensions.yaml JSON schema
  * feat(flake): update flake.lock
  * chore(container): update golangci/golangci-lint docker tag to
    v2.0.2
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.10.0-alpha.3
  * chore(container)!: Update golangci/golangci-lint Docker tag to
    v2
  * chore(github-action): update renovatebot/github-action action
    to v41.0.17
  * chore(schema): update talos-extensions.yaml JSON schema (#913)
  * chore(schema): update talos-extensions.yaml JSON schema (#909)
  * fix(deps): update module github.com/siderolabs/image-factory to
    v0.6.8
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(github-action): update actions/setup-go action to v5.4.0
  * chore(container): update golangci/golangci-lint docker tag to
    v1.64.8
  * chore(container): update mcr.microsoft.com/devcontainers/go
    docker tag to v1.24
  * chore(github-action): update renovatebot/github-action action
    to v41.0.16
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.23-bookworm docker digest
    to eaea1ec (#903)
  * chore(github-action): update renovatebot/github-action action
    to v41.0.15
  * chore(schema): update talos-extensions.yaml JSON schema (#900)
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.8.1
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.21
  * chore(schema): update talos-extensions.yaml JSON schema (#899)
  * feat: update Scoop for talhelper version v3.0.21
  * feat: update flake
  * docs: update CLI reference documentation (#895)
* Thu Mar 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.0.21:
  * chore(deps): update dependency siderolabs/talos to v1.9.5
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.9.5
  * chore(schema): update talos-extensions.yaml JSON schema (#894)
  * chore(container): update registry.k8s.io/kubectl docker tag to
    v1.32.3
  * chore(container): update golangci/golangci-lint docker tag to
    v1.64.7
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(schema): update talos-extensions.yaml JSON schema (#886)
  * chore(github-action)!: Update cachix/install-nix-action action
    to v31
  * chore(schema): update talos-extensions.yaml JSON schema
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.20
  * feat: update Scoop for talhelper version v3.0.20
  * feat: update flake (#882)
* Thu Mar  6 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.0.20:
  * fix(deps): update module golang.org/x/mod to v0.24.0
  * fix(deps): update module github.com/a8m/envsubst to v1.4.3
  * feat(flake): update go version
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.10.0-alpha.2
  * chore(schema): update talos-extensions.yaml JSON schema (#881)
  * chore(schema): update talos-extensions.yaml JSON schema (#878)
  * chore(container): update golangci/golangci-lint docker tag to
    v1.64.6
  * chore(schema): update talos-extensions.yaml JSON schema (#877)
  * docs: update discord ref id
  * chore(schema): update talos-extensions.yaml JSON schema
  * docs: fix typo
  * chore(schema): update talconfig.yaml JSON schema (#872)
  * feat(config): add node `certSANs` and deprecate
    `additionalMachineCertSans` (#869)
  * chore(github-action): update renovatebot/github-action action
    to v41.0.14
  * chore(schema): update talos-extensions.yaml JSON schema (#867)
  * docs: update CLI reference documentation (#866)
  * feat(gencommand): add shorthand for `--env-file` flag to match
    genconfig
  * chore(schema): update talos-extensions.yaml JSON schema
  * fix(deps): update module github.com/spf13/cobra to v1.9.1
  * fix(deps): update module github.com/spf13/cobra to v1.9.0
  * fix(validate_talconfig): only exit 1 when there are errors
  * chore(container): update alpine docker tag to v3.21.3
  * chore(schema): update talos-extensions.yaml JSON schema
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.19
  * feat: update Scoop for talhelper version v3.0.19
  * feat: update flake (#857)
* Fri Feb 14 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.0.19:
  * docs: update CLI reference documentation (#856)
  * chore(deps): update dependency siderolabs/talos to v1.9.4
  * chore(container): update golangci/golangci-lint docker tag to
    v1.64.5
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.9.4
  * chore(container): update registry.k8s.io/kubectl docker tag to
    v1.32.2
  * chore(container): update golangci/golangci-lint docker tag to
    v1.64.4
  * chore(devcontainer): Swap kubectl install image to use
    registry.k8s.io instead of bitnami (#848)
  * chore(schema): update talos-extensions.yaml JSON schema (#850)
  * chore(container): update golangci/golangci-lint docker tag to
    v1.64.2
  * chore(schema): update talos-extensions.yaml JSON schema (#847)
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.7.0
  * chore(schema): update talos-extensions.yaml JSON schema (#844)
  * chore(github-action): update renovatebot/github-action action
    to v41.0.13
  * chore(schema): update talconfig.yaml JSON schema (#842)
  * feat(code): add test for content substitution
  * feat(config): add `inlineManifests`
  * feat(config): allow `machineFiles` to be not envsubst-ed
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.18
  * feat: update Scoop for talhelper version v3.0.18
  * feat: update flake (#839)
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.0.18:
  * feat(validate_talconfig): exit with code 1 when issues found
  * fix(deps): update module golang.org/x/mod to v0.23.0
  * fix(deps): update module github.com/siderolabs/image-factory to
    v0.6.7
  * chore(github-action): update renovatebot/github-action action
    to v41.0.12
  * chore(schema): update talos-extensions.yaml JSON schema (#835)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.17
  * feat: update Scoop for talhelper version v3.0.17
  * feat: update flake (#829)
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.0.17:
  * docs: update CLI reference documentation (#828)
  * chore(deps): update dependency siderolabs/talos to v1.9.3
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.10.0-alpha.1
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.9.3
  * fix(deps): update module github.com/evanphx/json-patch to
    v5.9.11+incompatible
  * chore(github-action): update renovatebot/github-action action
    to v41.0.11
  * chore(container): update ghcr.io/getsops/sops docker tag to
    v3.9.4
  * fix(deps): update module github.com/getsops/sops/v3 to v3.9.4
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.6.1
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.6.0
  * chore(schema): update talos-extensions.yaml JSON schema (#817)
  * chore(github-action): update actions/setup-go action to v5.3.0
  * chore(schema): update talos-extensions.yaml JSON schema
  * fix(deps): update module github.com/siderolabs/image-factory to
    v0.6.6
  * chore(github-action): update renovatebot/github-action action
    to v41.0.10
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.16
  * feat: update Scoop for talhelper version v3.0.16
  * feat: update flake (#811)
* Sun Jan 19 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.0.16:
  * fix: use the commit where `busPath` is not broken
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.15
  * feat: update Scoop for talhelper version v3.0.15
  * feat: update flake (#808)
* Fri Jan 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.0.15:
  * feat: add v1.10 to supported version
  * docs: update CLI reference documentation (#807)
  * chore(deps): update dependency siderolabs/talos to v1.9.2
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.9.2
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(github-action): update renovatebot/github-action action
    to v41.0.9
  * fix(deps): update module github.com/google/go-containerregistry
    to v0.20.3
  * chore(container): update bitnami/kubectl docker tag to v1.32.1
  * chore(schema): update talos-extensions.yaml JSON schema (#799)
  * docs: update CLI reference documentation (#798)
  * chore(schema): update talconfig.yaml JSON schema (#797)
  * docs(config): update documentations
  * feat(config)!: rename `isoSchematic` to `imageSchematic`
  * feat(genurl)!: replace `genurl iso` subcommand with `genurl
    image`
  * chore(github-action): update renovatebot/github-action action
    to v41.0.8
  * chore(container): update alpine docker tag to v3.21.2
  * chore(schema): update talos-extensions.yaml JSON schema (#796)
  * feat(readme): thank you @roachmanfp for the sponsor!
  * chore(container): update golangci/golangci-lint docker tag to
    v1.63.4
  * fix(go): fix go refusing to run
  * fix(deps): update module github.com/getsops/sops/v3 to v3.9.3
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.5.1
  * chore(container): update golangci/golangci-lint docker tag to
    v1.63.3
  * fix(deps): update module github.com/invopop/jsonschema to
    v0.13.0
  * chore(schema): update talconfig.yaml JSON schema (#788)
  * chore(container): update ghcr.io/getsops/sops docker tag to
    v3.9.3
  * docs(config): add docs for `volumes`
  * feat(config): ad `volumes` field for `VolumeConfig` manifest
  * chore(schema): update talos-extensions.yaml JSON schema
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.14
  * feat: update Scoop for talhelper version v3.0.14
  * feat: update flake (#777)
* Fri Dec 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.14:
  * fix(go): update go builder version for image-factory
  * fix(deps): update module github.com/siderolabs/image-factory to
  * v0.6.5
  * docs: update CLI reference documentation (#776)
  * chore(deps): update dependency siderolabs/talos to v1.9.1
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
  * to v1.9.1
  * chore(schema): update talos-extensions.yaml JSON schema
  * fix(deps): update module
  * github.com/siderolabs/talos/pkg/machinery to v1.10.0-alpha.0
  * chore(schema): update talos-extensions.yaml JSON schema (#772)
  * chore(github-action): update renovatebot/github-action action
  * to v41.0.7
  * fix(deps): update module github.com/gookit/validate to v1.5.4
  * chore(schema): update talos-extensions.yaml JSON schema (#768)
  * chore(schema): update talos-extensions.yaml JSON schema (#767)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
  * v3.0.13
  * feat: update Scoop for talhelper version v3.0.13
  * feat: update flake (#764)
* Wed Dec 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.13:
  * fix(goreleaser): fix typo in arm64v8 platform container build
  * docs: update CLI reference documentation (#762)
  * chore(container): update bitnami/kubectl docker tag to v1.32.0
  * chore(deps): update dependency siderolabs/talos to v1.9.0
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.9.0
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.9.0
  * feat(readme): thank you @qjoly for the sponsor!
  * chore(schema): update talos-extensions.yaml JSON schema (#761)
  * chore(schema): update talos-extensions.yaml JSON schema
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.12
  * feat(validate): add validator for `installDiskSelector`
  * feat: update flake
  * feat: update Scoop for talhelper version v3.0.12
* Mon Dec 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.12:
  * feat(debug): show the defined schematic in debug mode
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.5.0
  * chore(schema): update talos-extensions.yaml JSON schema (#752)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.11
  * feat: update Scoop for talhelper version v3.0.11
  * feat: update flake (#750)
* Sat Dec 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.11:
  * docs: update CLI reference documentation (#749)
  * chore(deps): update dependency siderolabs/talos to v1.8.4
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.8.4
  * feat(readme): thank you @DrMxrcy for the sponsor!
  * chore(schema): update talos-extensions.yaml JSON schema (#748)
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.23-bookworm docker digest
    to a417a34 (#744)
  * chore(schema): update talos-extensions.yaml JSON schema (#745)
  * fix(deps): update module github.com/gookit/validate to v1.5.3
  * fix(deps): update module github.com/siderolabs/image-factory to
    v0.6.3
  * chore(schema): update talos-extensions.yaml JSON schema (#743)
  * chore(github-action): update actions/setup-go action to v5.2.0
  * chore(container): update bitnami/kubectl docker tag to v1.31.4
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.9.0-beta.1
  * chore(schema): update talos-extensions.yaml JSON schema (#739)
  * chore(github-action): update renovatebot/github-action action
    to v41.0.6
  * chore(schema): update talos-extensions.yaml JSON schema (#736)
  * chore(container): update alpine docker tag to v3.21.0
  * chore(schema): update talos-extensions.yaml JSON schema (#734)
  * chore(schema): update talos-extensions.yaml JSON schema (#732)
  * fix(deps): update module github.com/getsops/sops/v3 to v3.9.2
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.9.0-beta.0
  * chore(container): update ghcr.io/getsops/sops docker tag to
    v3.9.2
  * fix(deps): update module github.com/siderolabs/image-factory to
    v0.6.2
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(github-action): update renovatebot/github-action action
    to v41.0.5
  * chore(schema): update talos-extensions.yaml JSON schema (#726)
  * chore(schema): update talos-extensions.yaml JSON schema (#724)
  * chore(schema): update talos-extensions.yaml JSON schema (#723)
  * chore(github-action): update renovatebot/github-action action
    to v41.0.4
  * chore(container): update golangci/golangci-lint docker tag to
    v1.62.2
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.9.0-alpha.3
  * chore(schema): update talos-extensions.yaml JSON schema (#722)
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.4.8
  * feat(readme): thank you @Toastyice for the generous sponsor!
  * chore(container): update bitnami/kubectl docker tag to v1.31.3
  * chore(schema): update talos-extensions.yaml JSON schema (#716)
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.4.7
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.4.6
  * feat(flake): update flake.lock file for go v1.23.3
  * fix(deps): update module github.com/siderolabs/image-factory to
    v0.6.1
  * chore(github-action): update renovatebot/github-action action
    to v41.0.3
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.10
  * feat: update Scoop for talhelper version v3.0.10
  * feat: update flake
* Fri Nov 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.10:
  * chore(schema): update talconfig.yaml JSON schema (#709)
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.4.5
  * feat(genconfig): support templating node labels and annotations
  * docs: update CLI reference documentation (#706)
  * chore(deps): update dependency siderolabs/talos to v1.8.3
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.8.3
  * chore(schema): update talos-extensions.yaml JSON schema (#705)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.9
  * chore(schema): update talos-extensions.yaml JSON schema (#702)
  * chore(container): update alpine:3.20.3 docker digest to 1e42bbe
  * feat: update Scoop for talhelper version v3.0.9
  * feat: update flake
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.9:
  * chore(schema): update talos-extensions.yaml JSON schema (#697)
  * chore(container): update golangci/golangci-lint docker tag to
    v1.62.0
  * chore(github-action)!: Update renovatebot/github-action action
    to v41
  * chore(schema): update talos-extensions.yaml JSON schema (#695)
  * chore(github-action): update renovatebot/github-action action
    to v40.3.6
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.9.0-alpha.2
  * chore(schema): update talos-extensions.yaml JSON schema (#694)
  * fix(deps): update module golang.org/x/mod to v0.22.0
  * chore(schema): update talos-extensions.yaml JSON schema (#690)
  * docs: wrong indentation
  * fix(CI): the test-nix-build was wrongfully made all this time
  * chore(schema): update talos-extensions.yaml JSON schema (#688)
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.4.4
  * chore(schema): update talos-extensions.yaml JSON schema (#686)
  * chore(github-action): update renovatebot/github-action action
    to v40.3.5
  * feat: add v1.9 as supported version
  * feat(readme): Thank you @otosky for the sponsor!
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.4.1
  * chore(schema): update talos-extensions.yaml JSON schema (#683)
  * chore(schema): update talconfig.yaml JSON schema (#681)
  * feat(config): add `isoSchematic` for `genurl iso` if defined
  * chore(schema): update talos-extensions.yaml JSON schema (#680)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.8
  * feat: update flake (#678)
  * feat(flake): update flake.lock
  * chore(deps): update dependency go to v1.23.2
  * feat: update Scoop for talhelper version v3.0.8
* Wed Oct 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.8:
  * docs: update CLI reference documentation (#675)
  * chore(deps): update dependency siderolabs/talos to v1.8.2
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.8.2
  * chore(schema): update talos-extensions.yaml JSON schema (#674)
  * feat(readme): Thank you @eocx for the sponsor!
  * chore(github-action): update actions/setup-go action to v5.1.0
  * chore(schema): update talos-extensions.yaml JSON schema (#670)
  * chore(container): update bitnami/kubectl docker tag to v1.31.2
  * chore(github-action): update actions/checkout action to v4.2.2
  * chore(schema): update talos-extensions.yaml JSON schema (#668)
  * chore(github-action): update actions/checkout digest to 11bd719
  * chore(schema): update talos-extensions.yaml JSON schema
  * fix(deps): update module github.com/fatih/color to v1.18.0
  * chore(schema): update talos-extensions.yaml JSON schema (#662)
  * fix(flake): Update package to be talhelper not default
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.9.0-alpha.0
  * feat: add talhelper package and docs
  * feat: add easy overlay for flake parts
  * chore(schema): update talos-extensions.yaml JSON schema (#659)
  * docs(refs): re add the `machineDisks` that was accidentally
    deleted
  * chore(schema): update talos-extensions.yaml JSON schema (#657)
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.23-bookworm docker digest
    to 2e00578
  * chore(github-action): update renovatebot/github-action action
    to v40.3.4
  * fix(genconfig): skip applying patch that contains empty file
  * Set meta.mainProgram
  * chore(github-action): update renovatebot/github-action action
    to v40.3.3
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.7
  * feat: update Scoop for talhelper version v3.0.7
  * feat: update flake (#646)
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.7:
  * fix: change map type from `map[interface{}]interface{}` to
    `map[string]interface{}`
  * feat(deps): update `gopkg.in/yaml` to v3 for substitute package
  * fix(deps)!: Update module gopkg.in/yaml.v2 to v3
  * chore(github-action): update renovatebot/github-action action
    to v40.3.2
  * fix(CI): don't need `flakes-from-devshell` and typo
  * feat(CI): add test nix build workflow
  * docs: update CLI reference documentation (#643)
  * chore(deps): update dependency siderolabs/talos to v1.8.1
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.8.1
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.8.1
  * chore(schema): update talos-extensions.yaml JSON schema (#642)
  * chore(github-action): update actions/checkout action to v4.2.1
  * chore(github-action): update actions/checkout digest to eef6144
  * fix(deps): update module github.com/getsops/sops/v3 to v3.9.1
  * chore(container): update ghcr.io/getsops/sops docker tag to
    v3.9.1
  * chore(github-action)!: Update cachix/install-nix-action action
    to v30
  * chore(schema): update talos-extensions.yaml JSON schema (#632)
  * chore(github-action): update renovatebot/github-action action
    to v40.3.1
  * fix: Add support for relative paths when called from another
    dir (#619)
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.23-bookworm docker digest
    to 16c623a
  * chore(github-action): update renovatebot/github-action action
    to v40.2.11
  * chore(github-action)!: Update cachix/install-nix-action action
    to v29
  * chore(schema): update talos-extensions.yaml JSON schema (#625)
  * chore(github-action): update actions/checkout action to v4.2.0
  * chore(schema): update talos-extensions.yaml JSON schema (#623)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.6
  * feat(cmd): generate shell completion for `--node` flag
  * chore(container): update alpine:3.20.3 docker digest to beefdbd
  * chore(container): update alpine:3.20.3 docker digest to a8f1201
  * feat: update Scoop for talhelper version v3.0.6
  * feat: update flake (#617)
* Wed Sep 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.6:
  * docs: update CLI reference documentation (#616)
  * chore(deps): update dependency siderolabs/talos to v1.8.0
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.8.0
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.8.0
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.23-bookworm docker digest
    to fa6dbb5
  * chore(schema): update talos-extensions.yaml JSON schema (#615)
  * chore(github-action): update workflow/nix-shell-action action
    to v3.4.0
  * chore(schema): update talos-extensions.yaml JSON schema (#610)
  * chore(schema): update talos-extensions.yaml JSON schema (#608)
  * chore(schema): update talos-extensions.yaml JSON schema (#607)
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.3.2
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.8.0-beta.1
  * chore(github-action): update renovatebot/github-action action
    to v40.2.10
  * chore(schema): update talos-extensions.yaml JSON schema (#606)
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.23-bookworm docker digest
    to 089dc0f
  * chore(schema): update talos-extensions.yaml JSON schema (#604)
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.3.1
  * chore(schema): update talos-extensions.yaml JSON schema (#600)
  * chore(container): update bitnami/kubectl docker tag to v1.31.1
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.3.0
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.23-bookworm docker digest
    to 9fbee73
  * ci: Use goreleaser to build docker images (#589)
  * chore(schema): update talos-extensions.yaml JSON schema (#594)
  * ci: Add dry-run flag to goreleaser (#588)
  * chore(schema): update talos-extensions.yaml JSON schema (#593)
  * chore(container): update golangci/golangci-lint docker tag to
    v1.61.0
  * add a github workflow to make sure devcontainer image builds
  * update devcontainer configuration to custom docker image
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.8.0-beta.0
  * chore(schema): update talos-extensions.yaml JSON schema
  * feat(CI): use `gh` to auto merge PR
  * chore(goreleaser): migrate to v2
  * chore(github-action)!: Update goreleaser/goreleaser-action
    action to v6
  * chore(github-action): update renovatebot/github-action action
    to v40.2.8
  * address suggested improvements from review
  * add test for some comment stripping corner cases
  * use full yaml parsing to do comment stripping
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(schema): update talconfig.yaml JSON schema (#582)
  * feat(config): add support for `nodeAnnotations`
  * fix(deps): update module golang.org/x/mod to v0.21.0
  * chore(github-action)!: Update peter-evans/create-pull-request
    action to v7
  * fix(deps): update module github.com/siderolabs/image-factory to
    v0.5.0
  * chore(schema): update talconfig.yaml JSON schema (#574)
  * feat(config): reflect type changes from upstream to fix test
    failing
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.8.0-alpha.2
  * chore(schema): update talos-extensions.yaml JSON schema (#573)
  * chore(schema): update talos-extensions.yaml JSON schema (#571)
  * chore(schema): update talos-extensions.yaml JSON schema (#570)
  * chore(github-action): update renovatebot/github-action action
    to v40.2.7
  * feat: update go module to 1.23.0 and update flake
  * feat(code): shut up golangci-lint
  * chore(container): update golang docker tag to v1.23.0 (#560)
  * chore(schema): update talos-extensions.yaml JSON schema (#567)
  * chore(schema): update talos-extensions.yaml JSON schema (#566)
  * chore(github-action): update renovatebot/github-action action
    to v40.2.6
  * chore(schema): update talos-extensions.yaml JSON schema (#564)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.5
  * feat: update Scoop for talhelper version v3.0.5
  * feat: update flake (#562)
* Wed Aug  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.5:
  * docs: update CLI reference documentation (#561)
  * chore(deps): update dependency siderolabs/talos to v1.7.6
  * fix(deps): update module github.com/google/go-containerregistry
    to v0.20.2
  * chore(schema): update talos-extensions.yaml JSON schema (#559)
  * chore(github-action): update renovatebot/github-action action
    to v40.2.5
  * chore(schema): update talos-extensions.yaml JSON schema (#556)
  * fix(deps): update module golang.org/x/mod to v0.20.0
  * chore(schema): update talos-extensions.yaml JSON schema (#553)
  * chore(schema): update talos-extensions.yaml JSON schema (#552)
  * chore(schema): update talos-extensions.yaml JSON schema (#551)
  * chore(github-action): update renovatebot/github-action action
    to v40.2.4
  * feat(decrypt): add something to make `sops` error message
    friendlier
  * chore(schema): update talos-extensions.yaml JSON schema (#547)
  * chore(github-action): update renovatebot/github-action action
    to v40.2.3
  * fix(deps): update module github.com/google/go-containerregistry
    to v0.20.1
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.4
  * feat: update Scoop for talhelper version v3.0.4
  * feat: update flake (#540)
* Mon Jul 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.4:
  * chore(schema): update talconfig.yaml JSON schema (#539)
  * feat(config): add `noSchematicValidate` to skip schematic validation
  * feat(validate): don't validate on selfhosted image factory
  * chore(github-action)!: Update docker/build-push-action action to v6 (#511)
  * fix: Dockerfile base image and Docker Workflow (#536)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to v3.0.3
  * feat: update Scoop for talhelper version v3.0.3
  * feat: update flake (#533)
  * chore: bump flake to upstream go 1.22.5
  * feat(validate): give information about docs on config file not found
* Mon Jul 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package talhelper: tool to help creating Talos kubernetes
  cluster
